# Simulations on the TGCC clusters

## Clusters

http://www-hpc.cea.fr/fr/complexe/tgcc-JoliotCurie.htm

### SKL Irene (Skylake) (400000 h.CPU available)

- 1 656 nœuds fins bi-processeurs Intel Skylake 8168 à 2,7 GHz avec 24 coeurs par processeur
- 192 Go de mémoire DDR4/noeud

### KNL Irene (Knight Landing)

- 828 noeuds manycore Intel KNL 7250 à 1,4 GHz avec 68 coeurs par processeur
- 96 Go de mémoire DDR4 + 16 Go de mémoire MCDRAM/noeud

### Simulations

...